==> openshift-model-5.0.2-sources.jar: annotations/io/fabric8/openshift/api/model/CustomFeatureGatesFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CustomFeatureGatesFluent<A extends CustomFeatureGatesFluent<A>> extends Fluent<A> {


    public A addToDisabled(int index,String item);
    public A setToDisabled(int index,String item);
    public A addToDisabled(String... items);
    public A addAllToDisabled(Collection<String> items);
    public A removeFromDisabled(String... items);
    public A removeAllFromDisabled(Collection<String> items);
    public List<String> getDisabled();
    public String getDisabled(int index);
    public String getFirstDisabled();
    public String getLastDisabled();
    public String getMatchingDisabled(Predicate<String> predicate);
    public Boolean hasMatchingDisabled(Predicate<String> predicate);
    public A withDisabled(List<String> disabled);
    public A withDisabled(String... disabled);
    public Boolean hasDisabled();
    public A addNewDisabled(String arg1);
    public A addNewDisabled(StringBuilder arg1);
    public A addNewDisabled(StringBuffer arg1);
    public A addToEnabled(int index,String item);
    public A setToEnabled(int index,String item);
    public A addToEnabled(String... items);
    public A addAllToEnabled(Collection<String> items);
    public A removeFromEnabled(String... items);
    public A removeAllFromEnabled(Collection<String> items);
    public List<String> getEnabled();
    public String getEnabled(int index);
    public String getFirstEnabled();
    public String getLastEnabled();
    public String getMatchingEnabled(Predicate<String> predicate);
    public Boolean hasMatchingEnabled(Predicate<String> predicate);
    public A withEnabled(List<String> enabled);
    public A withEnabled(String... enabled);
    public Boolean hasEnabled();
    public A addNewEnabled(String arg1);
    public A addNewEnabled(StringBuilder arg1);
    public A addNewEnabled(StringBuffer arg1);
}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/CustomFeatureGatesFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CustomFeatureGatesFluent<A extends CustomFeatureGatesFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToDisabled(int index,String item);
    public A setToDisabled(int index,String item);
    public A addToDisabled(String... items);
    public A addAllToDisabled(Collection<String> items);
    public A removeFromDisabled(String... items);
    public A removeAllFromDisabled(Collection<String> items);
    public List<String> getDisabled();
    public String getDisabled(int index);
    public String getFirstDisabled();
    public String getLastDisabled();
    public String getMatchingDisabled(Predicate<String> predicate);
    public Boolean hasMatchingDisabled(Predicate<String> predicate);
    public A withDisabled(List<String> disabled);
    public A withDisabled(String... disabled);
    public Boolean hasDisabled();
    public A addNewDisabled(StringBuilder arg1);
    public A addNewDisabled(int[] arg1,int arg2,int arg3);
    public A addNewDisabled(char[] arg1);
    public A addNewDisabled(StringBuffer arg1);
    public A addNewDisabled(byte[] arg1,int arg2);
    public A addNewDisabled(byte[] arg1);
    public A addNewDisabled(char[] arg1,int arg2,int arg3);
    public A addNewDisabled(byte[] arg1,int arg2,int arg3);
    public A addNewDisabled(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewDisabled(String arg1);
    public A addToEnabled(int index,String item);
    public A setToEnabled(int index,String item);
    public A addToEnabled(String... items);
    public A addAllToEnabled(Collection<String> items);
    public A removeFromEnabled(String... items);
    public A removeAllFromEnabled(Collection<String> items);
    public List<String> getEnabled();
    public String getEnabled(int index);
    public String getFirstEnabled();
    public String getLastEnabled();
    public String getMatchingEnabled(Predicate<String> predicate);
    public Boolean hasMatchingEnabled(Predicate<String> predicate);
    public A withEnabled(List<String> enabled);
    public A withEnabled(String... enabled);
    public Boolean hasEnabled();
    public A addNewEnabled(StringBuilder arg1);
    public A addNewEnabled(int[] arg1,int arg2,int arg3);
    public A addNewEnabled(char[] arg1);
    public A addNewEnabled(StringBuffer arg1);
    public A addNewEnabled(byte[] arg1,int arg2);
    public A addNewEnabled(byte[] arg1);
    public A addNewEnabled(char[] arg1,int arg2,int arg3);
    public A addNewEnabled(byte[] arg1,int arg2,int arg3);
    public A addNewEnabled(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewEnabled(String arg1);
}
